summaryrefslogtreecommitdiff
path: root/sysdep
diff options
context:
space:
mode:
Diffstat (limited to 'sysdep')
-rw-r--r--sysdep/unix/krt.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/sysdep/unix/krt.c b/sysdep/unix/krt.c
index 794ebcd0..ded5dfe4 100644
--- a/sysdep/unix/krt.c
+++ b/sysdep/unix/krt.c
@@ -579,7 +579,7 @@ krt_export_net(struct krt_proto *p, net *net, rte **rt_free)
rte_make_tmp_attrs(&rt, krt_filter_lp);
/* We could run krt_import_control() here, but it is already handled by KRF_INSTALLED */
if (filter == FILTER_ACCEPT)
goto accept;
@@ -940,7 +940,7 @@ krt_store_tmp_attrs(rte *rt)
}
static int
-krt_import_control(struct proto *P, rte **new, struct linpool *pool UNUSED)
+krt_preexport(struct proto *P, rte **new, struct linpool *pool UNUSED)
{
// struct krt_proto *p = (struct krt_proto *) P;
rte *e = *new;
@@ -1085,7 +1085,7 @@ krt_init(struct proto_config *CF)
p->p.main_channel = proto_add_channel(&p->p, proto_cf_main_channel(CF));
- p->p.import_control = krt_import_control;
+ p->p.preexport = krt_preexport;
p->p.rt_notify = krt_rt_notify;
p->p.if_notify = krt_if_notify;
p->p.reload_routes = krt_reload_routes;
@@ -579,7 +579,7 @@ krt_export_net(struct krt_proto *p, net *net, rte **rt_free)
rte_make_tmp_attrs(&rt, krt_filter_lp);
- /* We could run krt_import_control() here, but it is already handled by KRF_INSTALLED */
+ /* We could run krt_preexport() here, but it is already handled by KRF_INSTALLED */
if (filter == FILTER_ACCEPT)
goto accept;